@@ -5,7 +5,7 @@ package Devel::CheckLib;
 use 5.00405; #postfix foreach
 use strict;
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION = '1.03';
+$VERSION = '1.04';
 use Config qw(%Config);
 use Text::ParseWords 'quotewords';
 
@@ -217,6 +217,12 @@ sub assert_lib {
             push @incpaths, substr($arg, 2);
         }
     }
+    foreach my $arg (split(' ', $ENV{PERL_MM_OPT}||'')) {
+        push @incpaths, substr($arg, 2)
+            if $arg =~ /^-I/;
+        push @{$arg =~ /^-l/ ? \@libs : \@libpaths}, substr($arg, 2)
+            if($arg =~ /^-[lLR]/);
+    }
 
     my ($cc, $ld) = _findcc();
     my @missing;
